SLDAP3
======

.. image:: https://pypip.in/version/sldap3/badge.svg
    :target: https://pypi.python.org/pypi/sldap3/
    :alt: Latest Version

.. image:: https://travis-ci.org/cannatag/sldap3.svg?branch=master
    :target: https://travis-ci.org/cannatag/sldap3
    :alt: TRAVIS-CI build status for master branch

.. image:: https://pypip.in/license/sldap3/badge.svg
    :target: https://pypi.python.org/pypi/sldap3/
    :alt: License

sldap3 is a strictly RFC 4511 conforming LDAP V3 pure Python **server**. It's a sibling of the **ldap3** client LDAP library.

Home Page
---------

Project home page is https://github.com/cannatag/sldap3


Documentation
-------------

Documentation is available at http://sldap3.readthedocs.org


License
-------

The sldap3 project is open source software released under the **LGPL v3 license**.


PEP8 Compliance
---------------

sldap3 is PEP8 compliant, except for line length.


Download
--------

Package download is available at https://pypi.python.org/pypi/sldap3.


Install
-------

Install with **pip install sldap3**


Git repository
--------------

You can download the latest source at https://github.com/cannatag/sldap3


Continuous integration
----------------------

Continuous integration for testing is at https://travis-ci.org/cannatag/sldap3

Support
-------

You can submit support tickets on https://github.com/cannatag/sldap3/issues/new


Contact me
----------

For information and suggestions you can contact me at cannatag@gmail.com or you can also a support ticket on https://github.com/cannatag/sldap3/issues/new

Changelog
---------

* 0.0.4a0 2015.04.23
    - daemonization working properly
    - Thread and Process executors available

* 0.0.3a6 2015.04.21
    - Added backward compatability via the trollius package
    - Added Linux daemon capability
    - Added Windows service capability

* 0.0.3a0 2015.04.11
    - added extended operation structure
    - added multiple DSAs definition

* 0.0.2a 2015.03.13
    - Added event loop
    - Added bind (always successful) operation
    - Added unbind operation

= 0.0.1a4 2015.02.28
    - Fixed missing _version.json in MANIFEST.in

* 0.0.1a3 2015.02.27
    - Fixed auto versioning
    - Fixed auto changelog

* 0.0.1a1 2015.02.21
    - Added sphinx structure

* 0.0.1a0 - 2015.02.20
    - Initial project structure
